@@ -7,22 +7,41 @@ use vars qw/@ISA @EXPORT/;
 use XML::DT;
 use XML::DTDParser qw/ParseDTDFile/;
 
+=encoding utf-8
+
 =head1 NAME
 
 XML::Writer::Simple - Create XML files easily!
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.09';
 @ISA = qw/Exporter/;
-@EXPORT = (qw/powertag xml_header/);
+@EXPORT = (qw/powertag xml_header quote_entities/);
 our %PTAGS = ();
 our $MODULENAME = "XML::Writer::Simple";
 
 our $IS_HTML = 0;
 our %TAG_SET = (
                 html => {
-                         tags => [qw.html head body script meta a p i u b Tr td table th div span.]
+                         tags => [qw.a abbr acronym address area
+                                     b base bdo big blockquote body br button
+                                     caption cite code col colgroup
+                                     dd del dfn div dl dt
+                                     em
+                                     fieldset form frame frameset
+                                     h1 h2 h3 h4 h5 h6 head hr html
+                                     i iframe img input ins
+                                     kbd
+                                     label legend li link
+                                     map meta
+                                     noframes noscript
+                                     object ol optgroup option
+                                     p param pre
+                                     q
+                                     samp script select small span strong style sub sup
+                                     table tbody td textarea tfoot th thead title Tr tt
+                                     u ul var.]
                         },
                );
 
@@ -140,6 +159,13 @@ Powertags support three level tags as well:
 
   print table_tr_td(['a','b','c'],['d','e','f']);
 
+=head2 quote_entities
+
+To use the special characters C<< < >>, C<< > >> and C<< & >> on your PCDATA content you need
+to protect them. You can either do that yourself or call this function.
+
+   print f(quote_entities("a < b"));
+
 =cut
 
 sub xml_header {
@@ -231,10 +257,30 @@ sub AUTOLOAD {
     }
 }
 
+sub quote_entities {
+	my $s = shift;
+	$s =~ s/&/&amp;/g;
+	$s =~ s/</&lt;/g;
+    $s =~ s/>/&gt;/g;
+	return $s;
+}
+
+sub _quote_attr {
+	my $s = shift;
+	$s =~ s/&/&amp;/g;
+	$s =~ s/"/&quot;/g;
+	return $s;
+}
+
+sub _attributes {
+	my $attr = shift;
+	return join(" ", map { "$_=\"" . _quote_attr($attr->{$_}) . "\""} keys %$attr);
+}
+
 sub _start_tag {
-	my ($tag,$attr) = @_;
-        $tag = "tr" if $tag eq "Tr" && $IS_HTML;
-	$attr = join(" ",map { "$_=\"$attr->{$_}\""} keys %$attr);
+	my ($tag, $attr) = @_;
+    $tag = "tr" if $tag eq "Tr" && $IS_HTML;
+	$attr = _attributes($attr);
 	if ($attr) {
 		return "<$tag $attr>"
 	} else {
@@ -243,9 +289,9 @@ sub _start_tag {
 }
 
 sub _empty_tag {
-	my ($tag,$attr) = @_;
-        $tag = "tr" if $tag eq "Tr" && $IS_HTML;
-	$attr = join(" ",map { "$_=\"$attr->{$_}\""} keys %$attr);
+	my ($tag, $attr) = @_;
+    $tag = "tr" if $tag eq "Tr" && $IS_HTML;
+	$attr = _attributes($attr);
 	if ($attr) {
 		return "<$tag $attr/>"
 	} else {
@@ -255,7 +301,7 @@ sub _empty_tag {
 
 sub _close_tag {
 	my $tag = shift;
-        $tag = "tr" if $tag eq "Tr" && $IS_HTML;
+    $tag = "tr" if $tag eq "Tr" && $IS_HTML;
 	return "</$tag>";
 }
 
@@ -316,7 +362,7 @@ sub import {
 
 =head1 AUTHOR
 
-Alberto Simoes, C<< <ambs@cpan.org> >>
+Alberto Simões, C<< <ambs@cpan.org> >>
 
 =head1 BUGS
 
@@ -326,14 +372,12 @@ L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=XML-Writer-Simple>.
 I will be notified, and then you'll automatically be notified of progress on
 your bug as I make changes.
 
-=head1 ACKNOWLEDGEMENTS
+=head1 COPYRIGHT AND LICENSE
 
-=head1 COPYRIGHT & LICENSE
+Copyright 1999-2012 Project Natura.
 
-Copyright 2006 Alberto Simoes, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
 
